Bedrijfsgegevens

# Form test

Introductory text.

Address block (More information) Address
Postal Code
City
Concise pattern text input Concise checkbox pattern Concise select pattern
Datum (Datum waarop de gegevens verzameld zijn) Day Month
Year
Radio list with explanations Maximaal 40 uur betaalde arbeid per week
(alle werknemers samen) Maximaal 25 werknemers
(let op het gaat hier niet om FTE’s, maar om daadwerkelijke personen)
Radio list with answer help Maximaal 40 uur betaalde arbeid per week
(More information) Maximaal 25 werknemers
(More information)
Percentage (Concise context)
Datum van akkoord OR/medewerkersvertegenwoordiging Day Month
Year

1. Voorbereiden
2. Inventariseren
3. Evalueren
4. Plan van aanpak
5. Rapporten

Link to sector organisation | Disclaimer | Design by Cornae